API Reference
=============

This page provides an auto-generated summary of esmlab’s API.
For more details and examples, refer to the relevant chapters in the main part of the documentation.


.. currentmodule:: esmlab_regrid.core


.. autosummary::
   Regridder



.. autoclass:: Regridder
   :members:

   .. automethod:: __init__
   .. automethod:: __call__
